@@ -5,20 +5,16 @@ from mimetypes import guess_type
 from os.path import join
 
 from django.conf import settings
-from django.utils.encoding import iri_to_uri
 from django.conf.urls.defaults import patterns, url
 from django.contrib import admin
 from django.core.files.storage import FileSystemStorage
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
-from django.template import loader, Context
 from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.core.event_logs.models import EventLog
 from tendenci.core.perms.admin import TendenciBaseModelAdmin
-from tendenci.core.perms.utils import update_perms_and_save
 
 from tendenci.apps.forms_builder.forms.models import Form, Field, FormEntry, FieldEntry, Pricing
 from tendenci.apps.forms_builder.forms.settings import UPLOAD_ROOT
@@ -26,6 +22,7 @@ from tendenci.apps.forms_builder.forms.forms import FormAdminForm, FormForField,
 
 fs = FileSystemStorage(location=UPLOAD_ROOT)
 
+
 class PricingAdminForm(PricingForm):
     class Meta:
         model = Pricing
@@ -35,11 +32,13 @@ class PricingAdminForm(PricingForm):
                    'due_sore',
                   )
 
+
 class PricingAdmin(admin.StackedInline):
     model = Pricing
     form = PricingAdminForm
     extra = 0
 
+
 class FieldAdminForm(FormForField):
     class Meta:
         model = Field
@@ -51,6 +50,7 @@ class FieldAdmin(admin.TabularInline):
     extra = 0
     ordering = ("position",)
 
+
 class FormAdmin(TendenciBaseModelAdmin):
 
     inlines = (PricingAdmin, FieldAdmin,)
@@ -66,7 +66,7 @@ class FormAdmin(TendenciBaseModelAdmin):
         (None, {"fields": ("title", "slug", "intro", "response", "completion_url", "template")}),
         (_("Email"), {"fields": ('subject_template', "email_from", "email_copies", "send_email", "email_text")}),
         ('Permissions', {'fields': ('allow_anonymous_view',)}),
-        ('Advanced Permissions', {'classes': ('collapse',),'fields': (
+        ('Advanced Permissions', {'classes': ('collapse',), 'fields': (
             'user_perms',
             'member_perms',
             'group_perms',
